data

package
v0.0.0-...-9cb6926 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Chat_AccountStatus_name = map[int32]string{
		0: "Standard",
		1: "Premium",
	}
	Chat_AccountStatus_value = map[string]int32{
		"Standard": 0,
		"Premium":  1,
	}
)

Enum value maps for Chat_AccountStatus.

var (
	Chat_Modifier_Pos_name = map[int32]string{
		0: "naka",
		1: "shita",
		2: "ue",
	}
	Chat_Modifier_Pos_value = map[string]int32{
		"naka":  0,
		"shita": 1,
		"ue":    2,
	}
)

Enum value maps for Chat_Modifier_Pos.

var (
	Chat_Modifier_Size_name = map[int32]string{
		0: "medium",
		1: "small",
		2: "big",
	}
	Chat_Modifier_Size_value = map[string]int32{
		"medium": 0,
		"small":  1,
		"big":    2,
	}
)

Enum value maps for Chat_Modifier_Size.

var (
	Chat_Modifier_ColorName_name = map[int32]string{
		0:  "white",
		1:  "red",
		2:  "pink",
		3:  "orange",
		4:  "yellow",
		5:  "green",
		6:  "cyan",
		7:  "blue",
		8:  "purple",
		9:  "black",
		10: "white2",
		11: "red2",
		12: "pink2",
		13: "orange2",
		14: "yellow2",
		15: "green2",
		16: "cyan2",
		17: "blue2",
		18: "purple2",
		19: "black2",
	}
	Chat_Modifier_ColorName_value = map[string]int32{
		"white":   0,
		"red":     1,
		"pink":    2,
		"orange":  3,
		"yellow":  4,
		"green":   5,
		"cyan":    6,
		"blue":    7,
		"purple":  8,
		"black":   9,
		"white2":  10,
		"red2":    11,
		"pink2":   12,
		"orange2": 13,
		"yellow2": 14,
		"green2":  15,
		"cyan2":   16,
		"blue2":   17,
		"purple2": 18,
		"black2":  19,
	}
)

Enum value maps for Chat_Modifier_ColorName.

var (
	Chat_Modifier_Font_name = map[int32]string{
		0: "defont",
		1: "mincho",
		2: "gothic",
	}
	Chat_Modifier_Font_value = map[string]int32{
		"defont": 0,
		"mincho": 1,
		"gothic": 2,
	}
)

Enum value maps for Chat_Modifier_Font.

var (
	Chat_Modifier_Opacity_name = map[int32]string{
		0: "Normal",
		1: "Translucent",
	}
	Chat_Modifier_Opacity_value = map[string]int32{
		"Normal":      0,
		"Translucent": 1,
	}
)

Enum value maps for Chat_Modifier_Opacity.

var (
	CommentLock_Status_name = map[int32]string{
		0: "Unrestricted",
		1: "Locked",
	}
	CommentLock_Status_value = map[string]int32{
		"Unrestricted": 0,
		"Locked":       1,
	}
)

Enum value maps for CommentLock_Status.

var (
	CommentMode_Layout_name = map[int32]string{
		0: "Normal",
		1: "SplitTop",
		2: "Background",
	}
	CommentMode_Layout_value = map[string]int32{
		"Normal":     0,
		"SplitTop":   1,
		"Background": 2,
	}
)

Enum value maps for CommentMode_Layout.

var (
	TrialPanel_Panel_name = map[int32]string{
		0: "Hidden",
		1: "Display",
	}
	TrialPanel_Panel_value = map[string]int32{
		"Hidden":  0,
		"Display": 1,
	}
)

Enum value maps for TrialPanel_Panel.

var (
	TrialPanel_Mode_name = map[int32]string{
		0: "Allowed",
		1: "Restricted",
		2: "Forbidden",
	}
	TrialPanel_Mode_value = map[string]int32{
		"Allowed":    0,
		"Restricted": 1,
		"Forbidden":  2,
	}
)

Enum value maps for TrialPanel_Mode.

var (
	ProgramStatus_State_name = map[int32]string{
		0: "Unknown",
		1: "Ended",
	}
	ProgramStatus_State_value = map[string]int32{
		"Unknown": 0,
		"Ended":   1,
	}
)

Enum value maps for ProgramStatus_State.

var (
	Enquete_Status_name = map[int32]string{
		0: "Closed",
		1: "Poll",
		2: "Result",
	}
	Enquete_Status_value = map[string]int32{
		"Closed": 0,
		"Poll":   1,
		"Result": 2,
	}
)

Enum value maps for Enquete_Status.

var File_dwango_nicolive_chat_data_atoms_proto protoreflect.FileDescriptor
var File_dwango_nicolive_chat_data_message_proto protoreflect.FileDescriptor
var File_dwango_nicolive_chat_data_origin_proto protoreflect.FileDescriptor
var File_dwango_nicolive_chat_data_state_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Chat

type Chat struct {
	Content       string             `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	Vpos          int32              `protobuf:"varint,3,opt,name=vpos,proto3" json:"vpos,omitempty"`
	AccountStatus Chat_AccountStatus `` /* 151-byte string literal not displayed */
	Name          *string            `protobuf:"bytes,2,opt,name=name,proto3,oneof" json:"name,omitempty"`
	RawUserId     *int64             `protobuf:"varint,5,opt,name=raw_user_id,json=rawUserId,proto3,oneof" json:"raw_user_id,omitempty"`
	HashedUserId  *string            `protobuf:"bytes,6,opt,name=hashed_user_id,json=hashedUserId,proto3,oneof" json:"hashed_user_id,omitempty"`
	Modifier      *Chat_Modifier     `protobuf:"bytes,7,opt,name=modifier,proto3" json:"modifier,omitempty"`
	No            int32              `protobuf:"varint,8,opt,name=no,proto3" json:"no,omitempty"`
	// contains filtered or unexported fields
}

func (*Chat) Descriptor deprecated

func (*Chat) Descriptor() ([]byte, []int)

Deprecated: Use Chat.ProtoReflect.Descriptor instead.

func (*Chat) GetAccountStatus

func (x *Chat) GetAccountStatus() Chat_AccountStatus

func (*Chat) GetContent

func (x *Chat) GetContent() string

func (*Chat) GetHashedUserId

func (x *Chat) GetHashedUserId() string

func (*Chat) GetModifier

func (x *Chat) GetModifier() *Chat_Modifier

func (*Chat) GetName

func (x *Chat) GetName() string

func (*Chat) GetNo

func (x *Chat) GetNo() int32

func (*Chat) GetRawUserId

func (x *Chat) GetRawUserId() int64

func (*Chat) GetVpos

func (x *Chat) GetVpos() int32

func (*Chat) ProtoMessage

func (*Chat) ProtoMessage()

func (*Chat) ProtoReflect

func (x *Chat) ProtoReflect() protoreflect.Message

func (*Chat) Reset

func (x *Chat) Reset()

func (*Chat) String

func (x *Chat) String() string

type Chat_AccountStatus

type Chat_AccountStatus int32
const (
	Chat_Standard Chat_AccountStatus = 0
	Chat_Premium  Chat_AccountStatus = 1
)

func (Chat_AccountStatus) Descriptor

func (Chat_AccountStatus) Enum

func (Chat_AccountStatus) EnumDescriptor deprecated

func (Chat_AccountStatus) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_AccountStatus.Descriptor instead.

func (Chat_AccountStatus) Number

func (Chat_AccountStatus) String

func (x Chat_AccountStatus) String() string

func (Chat_AccountStatus) Type

type Chat_Modifier

type Chat_Modifier struct {
	Position Chat_Modifier_Pos  `protobuf:"varint,1,opt,name=position,proto3,enum=dwango.nicolive.chat.data.Chat_Modifier_Pos" json:"position,omitempty"`
	Size     Chat_Modifier_Size `protobuf:"varint,2,opt,name=size,proto3,enum=dwango.nicolive.chat.data.Chat_Modifier_Size" json:"size,omitempty"`
	// Types that are valid to be assigned to Color:
	//
	//	*Chat_Modifier_NamedColor
	//	*Chat_Modifier_FullColor_
	Color   isChat_Modifier_Color `protobuf_oneof:"color"`
	Font    Chat_Modifier_Font    `protobuf:"varint,5,opt,name=font,proto3,enum=dwango.nicolive.chat.data.Chat_Modifier_Font" json:"font,omitempty"`
	Opacity Chat_Modifier_Opacity `protobuf:"varint,6,opt,name=opacity,proto3,enum=dwango.nicolive.chat.data.Chat_Modifier_Opacity" json:"opacity,omitempty"`
	// contains filtered or unexported fields
}

func (*Chat_Modifier) Descriptor deprecated

func (*Chat_Modifier) Descriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier.ProtoReflect.Descriptor instead.

func (*Chat_Modifier) GetColor

func (x *Chat_Modifier) GetColor() isChat_Modifier_Color

func (*Chat_Modifier) GetFont

func (x *Chat_Modifier) GetFont() Chat_Modifier_Font

func (*Chat_Modifier) GetFullColor

func (x *Chat_Modifier) GetFullColor() *Chat_Modifier_FullColor

func (*Chat_Modifier) GetNamedColor

func (x *Chat_Modifier) GetNamedColor() Chat_Modifier_ColorName

func (*Chat_Modifier) GetOpacity

func (x *Chat_Modifier) GetOpacity() Chat_Modifier_Opacity

func (*Chat_Modifier) GetPosition

func (x *Chat_Modifier) GetPosition() Chat_Modifier_Pos

func (*Chat_Modifier) GetSize

func (x *Chat_Modifier) GetSize() Chat_Modifier_Size

func (*Chat_Modifier) ProtoMessage

func (*Chat_Modifier) ProtoMessage()

func (*Chat_Modifier) ProtoReflect

func (x *Chat_Modifier) ProtoReflect() protoreflect.Message

func (*Chat_Modifier) Reset

func (x *Chat_Modifier) Reset()

func (*Chat_Modifier) String

func (x *Chat_Modifier) String() string

type Chat_Modifier_ColorName

type Chat_Modifier_ColorName int32
const (
	Chat_Modifier_white   Chat_Modifier_ColorName = 0
	Chat_Modifier_red     Chat_Modifier_ColorName = 1
	Chat_Modifier_pink    Chat_Modifier_ColorName = 2
	Chat_Modifier_orange  Chat_Modifier_ColorName = 3
	Chat_Modifier_yellow  Chat_Modifier_ColorName = 4
	Chat_Modifier_green   Chat_Modifier_ColorName = 5
	Chat_Modifier_cyan    Chat_Modifier_ColorName = 6
	Chat_Modifier_blue    Chat_Modifier_ColorName = 7
	Chat_Modifier_purple  Chat_Modifier_ColorName = 8
	Chat_Modifier_black   Chat_Modifier_ColorName = 9
	Chat_Modifier_white2  Chat_Modifier_ColorName = 10
	Chat_Modifier_red2    Chat_Modifier_ColorName = 11
	Chat_Modifier_pink2   Chat_Modifier_ColorName = 12
	Chat_Modifier_orange2 Chat_Modifier_ColorName = 13
	Chat_Modifier_yellow2 Chat_Modifier_ColorName = 14
	Chat_Modifier_green2  Chat_Modifier_ColorName = 15
	Chat_Modifier_cyan2   Chat_Modifier_ColorName = 16
	Chat_Modifier_blue2   Chat_Modifier_ColorName = 17
	Chat_Modifier_purple2 Chat_Modifier_ColorName = 18
	Chat_Modifier_black2  Chat_Modifier_ColorName = 19
)

func (Chat_Modifier_ColorName) Descriptor

func (Chat_Modifier_ColorName) Enum

func (Chat_Modifier_ColorName) EnumDescriptor deprecated

func (Chat_Modifier_ColorName) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_ColorName.Descriptor instead.

func (Chat_Modifier_ColorName) Number

func (Chat_Modifier_ColorName) String

func (x Chat_Modifier_ColorName) String() string

func (Chat_Modifier_ColorName) Type

type Chat_Modifier_Font

type Chat_Modifier_Font int32
const (
	Chat_Modifier_defont Chat_Modifier_Font = 0
	Chat_Modifier_mincho Chat_Modifier_Font = 1
	Chat_Modifier_gothic Chat_Modifier_Font = 2
)

func (Chat_Modifier_Font) Descriptor

func (Chat_Modifier_Font) Enum

func (Chat_Modifier_Font) EnumDescriptor deprecated

func (Chat_Modifier_Font) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_Font.Descriptor instead.

func (Chat_Modifier_Font) Number

func (Chat_Modifier_Font) String

func (x Chat_Modifier_Font) String() string

func (Chat_Modifier_Font) Type

type Chat_Modifier_FullColor

type Chat_Modifier_FullColor struct {
	R int32 `protobuf:"varint,1,opt,name=r,proto3" json:"r,omitempty"`
	G int32 `protobuf:"varint,2,opt,name=g,proto3" json:"g,omitempty"`
	B int32 `protobuf:"varint,3,opt,name=b,proto3" json:"b,omitempty"`
	// contains filtered or unexported fields
}

func (*Chat_Modifier_FullColor) Descriptor deprecated

func (*Chat_Modifier_FullColor) Descriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_FullColor.ProtoReflect.Descriptor instead.

func (*Chat_Modifier_FullColor) GetB

func (x *Chat_Modifier_FullColor) GetB() int32

func (*Chat_Modifier_FullColor) GetG

func (x *Chat_Modifier_FullColor) GetG() int32

func (*Chat_Modifier_FullColor) GetR

func (x *Chat_Modifier_FullColor) GetR() int32

func (*Chat_Modifier_FullColor) ProtoMessage

func (*Chat_Modifier_FullColor) ProtoMessage()

func (*Chat_Modifier_FullColor) ProtoReflect

func (x *Chat_Modifier_FullColor) ProtoReflect() protoreflect.Message

func (*Chat_Modifier_FullColor) Reset

func (x *Chat_Modifier_FullColor) Reset()

func (*Chat_Modifier_FullColor) String

func (x *Chat_Modifier_FullColor) String() string

type Chat_Modifier_FullColor_

type Chat_Modifier_FullColor_ struct {
	FullColor *Chat_Modifier_FullColor `protobuf:"bytes,4,opt,name=full_color,json=fullColor,proto3,oneof"`
}

type Chat_Modifier_NamedColor

type Chat_Modifier_NamedColor struct {
	NamedColor Chat_Modifier_ColorName `protobuf:"varint,3,opt,name=named_color,json=namedColor,proto3,enum=dwango.nicolive.chat.data.Chat_Modifier_ColorName,oneof"`
}

type Chat_Modifier_Opacity

type Chat_Modifier_Opacity int32
const (
	Chat_Modifier_Normal      Chat_Modifier_Opacity = 0
	Chat_Modifier_Translucent Chat_Modifier_Opacity = 1
)

func (Chat_Modifier_Opacity) Descriptor

func (Chat_Modifier_Opacity) Enum

func (Chat_Modifier_Opacity) EnumDescriptor deprecated

func (Chat_Modifier_Opacity) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_Opacity.Descriptor instead.

func (Chat_Modifier_Opacity) Number

func (Chat_Modifier_Opacity) String

func (x Chat_Modifier_Opacity) String() string

func (Chat_Modifier_Opacity) Type

type Chat_Modifier_Pos

type Chat_Modifier_Pos int32
const (
	Chat_Modifier_naka  Chat_Modifier_Pos = 0
	Chat_Modifier_shita Chat_Modifier_Pos = 1
	Chat_Modifier_ue    Chat_Modifier_Pos = 2
)

func (Chat_Modifier_Pos) Descriptor

func (Chat_Modifier_Pos) Enum

func (Chat_Modifier_Pos) EnumDescriptor deprecated

func (Chat_Modifier_Pos) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_Pos.Descriptor instead.

func (Chat_Modifier_Pos) Number

func (Chat_Modifier_Pos) String

func (x Chat_Modifier_Pos) String() string

func (Chat_Modifier_Pos) Type

type Chat_Modifier_Size

type Chat_Modifier_Size int32
const (
	Chat_Modifier_medium Chat_Modifier_Size = 0
	Chat_Modifier_small  Chat_Modifier_Size = 1
	Chat_Modifier_big    Chat_Modifier_Size = 2
)

func (Chat_Modifier_Size) Descriptor

func (Chat_Modifier_Size) Enum

func (Chat_Modifier_Size) EnumDescriptor deprecated

func (Chat_Modifier_Size) EnumDescriptor() ([]byte, []int)

Deprecated: Use Chat_Modifier_Size.Descriptor instead.

func (Chat_Modifier_Size) Number

func (Chat_Modifier_Size) String

func (x Chat_Modifier_Size) String() string

func (Chat_Modifier_Size) Type

type CommentLock

type CommentLock struct {
	Status CommentLock_Status `protobuf:"varint,1,opt,name=status,proto3,enum=dwango.nicolive.chat.data.CommentLock_Status" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*CommentLock) Descriptor deprecated

func (*CommentLock) Descriptor() ([]byte, []int)

Deprecated: Use CommentLock.ProtoReflect.Descriptor instead.

func (*CommentLock) GetStatus

func (x *CommentLock) GetStatus() CommentLock_Status

func (*CommentLock) ProtoMessage

func (*CommentLock) ProtoMessage()

func (*CommentLock) ProtoReflect

func (x *CommentLock) ProtoReflect() protoreflect.Message

func (*CommentLock) Reset

func (x *CommentLock) Reset()

func (*CommentLock) String

func (x *CommentLock) String() string

type CommentLock_Status

type CommentLock_Status int32
const (
	CommentLock_Unrestricted CommentLock_Status = 0
	CommentLock_Locked       CommentLock_Status = 1
)

func (CommentLock_Status) Descriptor

func (CommentLock_Status) Enum

func (CommentLock_Status) EnumDescriptor deprecated

func (CommentLock_Status) EnumDescriptor() ([]byte, []int)

Deprecated: Use CommentLock_Status.Descriptor instead.

func (CommentLock_Status) Number

func (CommentLock_Status) String

func (x CommentLock_Status) String() string

func (CommentLock_Status) Type

type CommentMode

type CommentMode struct {
	Layout CommentMode_Layout `protobuf:"varint,1,opt,name=layout,proto3,enum=dwango.nicolive.chat.data.CommentMode_Layout" json:"layout,omitempty"`
	// contains filtered or unexported fields
}

func (*CommentMode) Descriptor deprecated

func (*CommentMode) Descriptor() ([]byte, []int)

Deprecated: Use CommentMode.ProtoReflect.Descriptor instead.

func (*CommentMode) GetLayout

func (x *CommentMode) GetLayout() CommentMode_Layout

func (*CommentMode) ProtoMessage

func (*CommentMode) ProtoMessage()

func (*CommentMode) ProtoReflect

func (x *CommentMode) ProtoReflect() protoreflect.Message

func (*CommentMode) Reset

func (x *CommentMode) Reset()

func (*CommentMode) String

func (x *CommentMode) String() string

type CommentMode_Layout

type CommentMode_Layout int32
const (
	CommentMode_Normal     CommentMode_Layout = 0
	CommentMode_SplitTop   CommentMode_Layout = 1
	CommentMode_Background CommentMode_Layout = 2
)

func (CommentMode_Layout) Descriptor

func (CommentMode_Layout) Enum

func (CommentMode_Layout) EnumDescriptor deprecated

func (CommentMode_Layout) EnumDescriptor() ([]byte, []int)

Deprecated: Use CommentMode_Layout.Descriptor instead.

func (CommentMode_Layout) Number

func (CommentMode_Layout) String

func (x CommentMode_Layout) String() string

func (CommentMode_Layout) Type

type Enquete

type Enquete struct {
	Question string            `protobuf:"bytes,1,opt,name=question,proto3" json:"question,omitempty"`
	Choices  []*Enquete_Choice `protobuf:"bytes,2,rep,name=choices,proto3" json:"choices,omitempty"`
	Status   Enquete_Status    `protobuf:"varint,3,opt,name=status,proto3,enum=dwango.nicolive.chat.data.Enquete_Status" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*Enquete) Descriptor deprecated

func (*Enquete) Descriptor() ([]byte, []int)

Deprecated: Use Enquete.ProtoReflect.Descriptor instead.

func (*Enquete) GetChoices

func (x *Enquete) GetChoices() []*Enquete_Choice

func (*Enquete) GetQuestion

func (x *Enquete) GetQuestion() string

func (*Enquete) GetStatus

func (x *Enquete) GetStatus() Enquete_Status

func (*Enquete) ProtoMessage

func (*Enquete) ProtoMessage()

func (*Enquete) ProtoReflect

func (x *Enquete) ProtoReflect() protoreflect.Message

func (*Enquete) Reset

func (x *Enquete) Reset()

func (*Enquete) String

func (x *Enquete) String() string

type Enquete_Choice

type Enquete_Choice struct {
	Description string `protobuf:"bytes,1,opt,name=description,proto3" json:"description,omitempty"`
	PerMille    *int32 `protobuf:"varint,3,opt,name=per_mille,json=perMille,proto3,oneof" json:"per_mille,omitempty"`
	// contains filtered or unexported fields
}

func (*Enquete_Choice) Descriptor deprecated

func (*Enquete_Choice) Descriptor() ([]byte, []int)

Deprecated: Use Enquete_Choice.ProtoReflect.Descriptor instead.

func (*Enquete_Choice) GetDescription

func (x *Enquete_Choice) GetDescription() string

func (*Enquete_Choice) GetPerMille

func (x *Enquete_Choice) GetPerMille() int32

func (*Enquete_Choice) ProtoMessage

func (*Enquete_Choice) ProtoMessage()

func (*Enquete_Choice) ProtoReflect

func (x *Enquete_Choice) ProtoReflect() protoreflect.Message

func (*Enquete_Choice) Reset

func (x *Enquete_Choice) Reset()

func (*Enquete_Choice) String

func (x *Enquete_Choice) String() string

type Enquete_Status

type Enquete_Status int32
const (
	Enquete_Closed Enquete_Status = 0
	Enquete_Poll   Enquete_Status = 1
	Enquete_Result Enquete_Status = 2
)

func (Enquete_Status) Descriptor

func (Enquete_Status) Enum

func (x Enquete_Status) Enum() *Enquete_Status

func (Enquete_Status) EnumDescriptor deprecated

func (Enquete_Status) EnumDescriptor() ([]byte, []int)

Deprecated: Use Enquete_Status.Descriptor instead.

func (Enquete_Status) Number

func (Enquete_Status) String

func (x Enquete_Status) String() string

func (Enquete_Status) Type

type GameUpdate

type GameUpdate struct {
	// contains filtered or unexported fields
}

func (*GameUpdate) Descriptor deprecated

func (*GameUpdate) Descriptor() ([]byte, []int)

Deprecated: Use GameUpdate.ProtoReflect.Descriptor instead.

func (*GameUpdate) ProtoMessage

func (*GameUpdate) ProtoMessage()

func (*GameUpdate) ProtoReflect

func (x *GameUpdate) ProtoReflect() protoreflect.Message

func (*GameUpdate) Reset

func (x *GameUpdate) Reset()

func (*GameUpdate) String

func (x *GameUpdate) String() string

type Gift

type Gift struct {
	ItemId           string `protobuf:"bytes,1,opt,name=item_id,json=itemId,proto3" json:"item_id,omitempty"`
	AdvertiserUserId *int64 `protobuf:"varint,2,opt,name=advertiser_user_id,json=advertiserUserId,proto3,oneof" json:"advertiser_user_id,omitempty"`
	AdvertiserName   string `protobuf:"bytes,3,opt,name=advertiser_name,json=advertiserName,proto3" json:"advertiser_name,omitempty"`
	Point            int64  `protobuf:"varint,4,opt,name=point,proto3" json:"point,omitempty"`
	Message          string `protobuf:"bytes,5,opt,name=message,proto3" json:"message,omitempty"`
	ItemName         string `protobuf:"bytes,6,opt,name=item_name,json=itemName,proto3" json:"item_name,omitempty"`
	ContributionRank *int32 `protobuf:"varint,7,opt,name=contribution_rank,json=contributionRank,proto3,oneof" json:"contribution_rank,omitempty"`
	// contains filtered or unexported fields
}

func (*Gift) Descriptor deprecated

func (*Gift) Descriptor() ([]byte, []int)

Deprecated: Use Gift.ProtoReflect.Descriptor instead.

func (*Gift) GetAdvertiserName

func (x *Gift) GetAdvertiserName() string

func (*Gift) GetAdvertiserUserId

func (x *Gift) GetAdvertiserUserId() int64

func (*Gift) GetContributionRank

func (x *Gift) GetContributionRank() int32

func (*Gift) GetItemId

func (x *Gift) GetItemId() string

func (*Gift) GetItemName

func (x *Gift) GetItemName() string

func (*Gift) GetMessage

func (x *Gift) GetMessage() string

func (*Gift) GetPoint

func (x *Gift) GetPoint() int64

func (*Gift) ProtoMessage

func (*Gift) ProtoMessage()

func (*Gift) ProtoReflect

func (x *Gift) ProtoReflect() protoreflect.Message

func (*Gift) Reset

func (x *Gift) Reset()

func (*Gift) String

func (x *Gift) String() string

type Jump

type Jump struct {
	Content string               `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	Message string               `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	Wait    *durationpb.Duration `protobuf:"bytes,4,opt,name=wait,proto3" json:"wait,omitempty"`
	// contains filtered or unexported fields
}

func (*Jump) Descriptor deprecated

func (*Jump) Descriptor() ([]byte, []int)

Deprecated: Use Jump.ProtoReflect.Descriptor instead.

func (*Jump) GetContent

func (x *Jump) GetContent() string

func (*Jump) GetMessage

func (x *Jump) GetMessage() string

func (*Jump) GetWait

func (x *Jump) GetWait() *durationpb.Duration

func (*Jump) ProtoMessage

func (*Jump) ProtoMessage()

func (*Jump) ProtoReflect

func (x *Jump) ProtoReflect() protoreflect.Message

func (*Jump) Reset

func (x *Jump) Reset()

func (*Jump) String

func (x *Jump) String() string

type Marquee

type Marquee struct {
	Display *Marquee_Display `protobuf:"bytes,1,opt,name=display,proto3,oneof" json:"display,omitempty"`
	// contains filtered or unexported fields
}

func (*Marquee) Descriptor deprecated

func (*Marquee) Descriptor() ([]byte, []int)

Deprecated: Use Marquee.ProtoReflect.Descriptor instead.

func (*Marquee) GetDisplay

func (x *Marquee) GetDisplay() *Marquee_Display

func (*Marquee) ProtoMessage

func (*Marquee) ProtoMessage()

func (*Marquee) ProtoReflect

func (x *Marquee) ProtoReflect() protoreflect.Message

func (*Marquee) Reset

func (x *Marquee) Reset()

func (*Marquee) String

func (x *Marquee) String() string

type Marquee_Display

type Marquee_Display struct {
	OperatorComment *OperatorComment     `protobuf:"bytes,1,opt,name=operator_comment,json=operatorComment,proto3" json:"operator_comment,omitempty"`
	Duration        *durationpb.Duration `protobuf:"bytes,3,opt,name=duration,proto3,oneof" json:"duration,omitempty"`
	// contains filtered or unexported fields
}

func (*Marquee_Display) Descriptor deprecated

func (*Marquee_Display) Descriptor() ([]byte, []int)

Deprecated: Use Marquee_Display.ProtoReflect.Descriptor instead.

func (*Marquee_Display) GetDuration

func (x *Marquee_Display) GetDuration() *durationpb.Duration

func (*Marquee_Display) GetOperatorComment

func (x *Marquee_Display) GetOperatorComment() *OperatorComment

func (*Marquee_Display) ProtoMessage

func (*Marquee_Display) ProtoMessage()

func (*Marquee_Display) ProtoReflect

func (x *Marquee_Display) ProtoReflect() protoreflect.Message

func (*Marquee_Display) Reset

func (x *Marquee_Display) Reset()

func (*Marquee_Display) String

func (x *Marquee_Display) String() string

type MoveOrder

type MoveOrder struct {

	// Types that are valid to be assigned to To:
	//
	//	*MoveOrder_Jump
	//	*MoveOrder_Redirect
	To isMoveOrder_To `protobuf_oneof:"to"`
	// contains filtered or unexported fields
}

func (*MoveOrder) Descriptor deprecated

func (*MoveOrder) Descriptor() ([]byte, []int)

Deprecated: Use MoveOrder.ProtoReflect.Descriptor instead.

func (*MoveOrder) GetJump

func (x *MoveOrder) GetJump() *Jump

func (*MoveOrder) GetRedirect

func (x *MoveOrder) GetRedirect() *Redirect

func (*MoveOrder) GetTo

func (x *MoveOrder) GetTo() isMoveOrder_To

func (*MoveOrder) ProtoMessage

func (*MoveOrder) ProtoMessage()

func (*MoveOrder) ProtoReflect

func (x *MoveOrder) ProtoReflect() protoreflect.Message

func (*MoveOrder) Reset

func (x *MoveOrder) Reset()

func (*MoveOrder) String

func (x *MoveOrder) String() string

type MoveOrder_Jump

type MoveOrder_Jump struct {
	Jump *Jump `protobuf:"bytes,1,opt,name=jump,proto3,oneof"`
}

type MoveOrder_Redirect

type MoveOrder_Redirect struct {
	Redirect *Redirect `protobuf:"bytes,2,opt,name=redirect,proto3,oneof"`
}

type Nicoad

type Nicoad struct {

	// Types that are valid to be assigned to Versions:
	//
	//	*Nicoad_V0_
	//	*Nicoad_V1_
	Versions isNicoad_Versions `protobuf_oneof:"versions"`
	// contains filtered or unexported fields
}

func (*Nicoad) Descriptor deprecated

func (*Nicoad) Descriptor() ([]byte, []int)

Deprecated: Use Nicoad.ProtoReflect.Descriptor instead.

func (*Nicoad) GetV0

func (x *Nicoad) GetV0() *Nicoad_V0

func (*Nicoad) GetV1

func (x *Nicoad) GetV1() *Nicoad_V1

func (*Nicoad) GetVersions

func (x *Nicoad) GetVersions() isNicoad_Versions

func (*Nicoad) ProtoMessage

func (*Nicoad) ProtoMessage()

func (*Nicoad) ProtoReflect

func (x *Nicoad) ProtoReflect() protoreflect.Message

func (*Nicoad) Reset

func (x *Nicoad) Reset()

func (*Nicoad) String

func (x *Nicoad) String() string

type Nicoad_V0

type Nicoad_V0 struct {
	Latest     *Nicoad_V0_Latest    `protobuf:"bytes,1,opt,name=latest,proto3" json:"latest,omitempty"`
	Ranking    []*Nicoad_V0_Ranking `protobuf:"bytes,2,rep,name=ranking,proto3" json:"ranking,omitempty"`
	TotalPoint int32                `protobuf:"varint,3,opt,name=total_point,json=totalPoint,proto3" json:"total_point,omitempty"`
	// contains filtered or unexported fields
}

func (*Nicoad_V0) Descriptor deprecated

func (*Nicoad_V0) Descriptor() ([]byte, []int)

Deprecated: Use Nicoad_V0.ProtoReflect.Descriptor instead.

func (*Nicoad_V0) GetLatest

func (x *Nicoad_V0) GetLatest() *Nicoad_V0_Latest

func (*Nicoad_V0) GetRanking

func (x *Nicoad_V0) GetRanking() []*Nicoad_V0_Ranking

func (*Nicoad_V0) GetTotalPoint

func (x *Nicoad_V0) GetTotalPoint() int32

func (*Nicoad_V0) ProtoMessage

func (*Nicoad_V0) ProtoMessage()

func (*Nicoad_V0) ProtoReflect

func (x *Nicoad_V0) ProtoReflect() protoreflect.Message

func (*Nicoad_V0) Reset

func (x *Nicoad_V0) Reset()

func (*Nicoad_V0) String

func (x *Nicoad_V0) String() string

type Nicoad_V0_

type Nicoad_V0_ struct {
	V0 *Nicoad_V0 `protobuf:"bytes,1,opt,name=v0,proto3,oneof"`
}

type Nicoad_V0_Latest

type Nicoad_V0_Latest struct {
	Advertiser string  `protobuf:"bytes,1,opt,name=advertiser,proto3" json:"advertiser,omitempty"`
	Point      int32   `protobuf:"varint,2,opt,name=point,proto3" json:"point,omitempty"`
	Message    *string `protobuf:"bytes,3,opt,name=message,proto3,oneof" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*Nicoad_V0_Latest) Descriptor deprecated

func (*Nicoad_V0_Latest) Descriptor() ([]byte, []int)

Deprecated: Use Nicoad_V0_Latest.ProtoReflect.Descriptor instead.

func (*Nicoad_V0_Latest) GetAdvertiser

func (x *Nicoad_V0_Latest) GetAdvertiser() string

func (*Nicoad_V0_Latest) GetMessage

func (x *Nicoad_V0_Latest) GetMessage() string

func (*Nicoad_V0_Latest) GetPoint

func (x *Nicoad_V0_Latest) GetPoint() int32

func (*Nicoad_V0_Latest) ProtoMessage

func (*Nicoad_V0_Latest) ProtoMessage()

func (*Nicoad_V0_Latest) ProtoReflect

func (x *Nicoad_V0_Latest) ProtoReflect() protoreflect.Message

func (*Nicoad_V0_Latest) Reset

func (x *Nicoad_V0_Latest) Reset()

func (*Nicoad_V0_Latest) String

func (x *Nicoad_V0_Latest) String() string

type Nicoad_V0_Ranking

type Nicoad_V0_Ranking struct {
	Advertiser string  `protobuf:"bytes,1,opt,name=advertiser,proto3" json:"advertiser,omitempty"`
	Rank       int32   `protobuf:"varint,2,opt,name=rank,proto3" json:"rank,omitempty"`
	Message    *string `protobuf:"bytes,3,opt,name=message,proto3,oneof" json:"message,omitempty"`
	UserRank   *int32  `protobuf:"varint,4,opt,name=user_rank,json=userRank,proto3,oneof" json:"user_rank,omitempty"`
	// contains filtered or unexported fields
}

func (*Nicoad_V0_Ranking) Descriptor deprecated

func (*Nicoad_V0_Ranking) Descriptor() ([]byte, []int)

Deprecated: Use Nicoad_V0_Ranking.ProtoReflect.Descriptor instead.

func (*Nicoad_V0_Ranking) GetAdvertiser

func (x *Nicoad_V0_Ranking) GetAdvertiser() string

func (*Nicoad_V0_Ranking) GetMessage

func (x *Nicoad_V0_Ranking) GetMessage() string

func (*Nicoad_V0_Ranking) GetRank

func (x *Nicoad_V0_Ranking) GetRank() int32

func (*Nicoad_V0_Ranking) GetUserRank

func (x *Nicoad_V0_Ranking) GetUserRank() int32

func (*Nicoad_V0_Ranking) ProtoMessage

func (*Nicoad_V0_Ranking) ProtoMessage()

func (*Nicoad_V0_Ranking) ProtoReflect

func (x *Nicoad_V0_Ranking) ProtoReflect() protoreflect.Message

func (*Nicoad_V0_Ranking) Reset

func (x *Nicoad_V0_Ranking) Reset()

func (*Nicoad_V0_Ranking) String

func (x *Nicoad_V0_Ranking) String() string

type Nicoad_V1

type Nicoad_V1 struct {
	TotalAdPoint int32  `protobuf:"varint,1,opt,name=total_ad_point,json=totalAdPoint,proto3" json:"total_ad_point,omitempty"`
	Message      string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*Nicoad_V1) Descriptor deprecated

func (*Nicoad_V1) Descriptor() ([]byte, []int)

Deprecated: Use Nicoad_V1.ProtoReflect.Descriptor instead.

func (*Nicoad_V1) GetMessage

func (x *Nicoad_V1) GetMessage() string

func (*Nicoad_V1) GetTotalAdPoint

func (x *Nicoad_V1) GetTotalAdPoint() int32

func (*Nicoad_V1) ProtoMessage

func (*Nicoad_V1) ProtoMessage()

func (*Nicoad_V1) ProtoReflect

func (x *Nicoad_V1) ProtoReflect() protoreflect.Message

func (*Nicoad_V1) Reset

func (x *Nicoad_V1) Reset()

func (*Nicoad_V1) String

func (x *Nicoad_V1) String() string

type Nicoad_V1_

type Nicoad_V1_ struct {
	V1 *Nicoad_V1 `protobuf:"bytes,2,opt,name=v1,proto3,oneof"`
}

type NicoliveMessage

type NicoliveMessage struct {

	// Types that are valid to be assigned to Data:
	//
	//	*NicoliveMessage_Chat
	//	*NicoliveMessage_SimpleNotification
	//	*NicoliveMessage_Gift
	//	*NicoliveMessage_Nicoad
	//	*NicoliveMessage_GameUpdate
	//	*NicoliveMessage_TagUpdated
	//	*NicoliveMessage_ModeratorUpdated
	//	*NicoliveMessage_SsngUpdated
	//	*NicoliveMessage_OverflowedChat
	Data isNicoliveMessage_Data `protobuf_oneof:"data"`
	// contains filtered or unexported fields
}

func (*NicoliveMessage) Descriptor deprecated

func (*NicoliveMessage) Descriptor() ([]byte, []int)

Deprecated: Use NicoliveMessage.ProtoReflect.Descriptor instead.

func (*NicoliveMessage) GetChat

func (x *NicoliveMessage) GetChat() *Chat

func (*NicoliveMessage) GetData

func (x *NicoliveMessage) GetData() isNicoliveMessage_Data

func (*NicoliveMessage) GetGameUpdate

func (x *NicoliveMessage) GetGameUpdate() *GameUpdate

func (*NicoliveMessage) GetGift

func (x *NicoliveMessage) GetGift() *Gift

func (*NicoliveMessage) GetModeratorUpdated

func (x *NicoliveMessage) GetModeratorUpdated() *atoms.ModeratorUpdated

func (*NicoliveMessage) GetNicoad

func (x *NicoliveMessage) GetNicoad() *Nicoad

func (*NicoliveMessage) GetOverflowedChat

func (x *NicoliveMessage) GetOverflowedChat() *Chat

func (*NicoliveMessage) GetSimpleNotification

func (x *NicoliveMessage) GetSimpleNotification() *SimpleNotification

func (*NicoliveMessage) GetSsngUpdated

func (x *NicoliveMessage) GetSsngUpdated() *atoms.SSNGUpdated

func (*NicoliveMessage) GetTagUpdated

func (x *NicoliveMessage) GetTagUpdated() *TagUpdated

func (*NicoliveMessage) ProtoMessage

func (*NicoliveMessage) ProtoMessage()

func (*NicoliveMessage) ProtoReflect

func (x *NicoliveMessage) ProtoReflect() protoreflect.Message

func (*NicoliveMessage) Reset

func (x *NicoliveMessage) Reset()

func (*NicoliveMessage) String

func (x *NicoliveMessage) String() string

type NicoliveMessage_Chat

type NicoliveMessage_Chat struct {
	Chat *Chat `protobuf:"bytes,1,opt,name=chat,proto3,oneof"`
}

type NicoliveMessage_GameUpdate

type NicoliveMessage_GameUpdate struct {
	GameUpdate *GameUpdate `protobuf:"bytes,13,opt,name=game_update,json=gameUpdate,proto3,oneof"`
}

type NicoliveMessage_Gift

type NicoliveMessage_Gift struct {
	Gift *Gift `protobuf:"bytes,8,opt,name=gift,proto3,oneof"`
}

type NicoliveMessage_ModeratorUpdated

type NicoliveMessage_ModeratorUpdated struct {
	ModeratorUpdated *atoms.ModeratorUpdated `protobuf:"bytes,18,opt,name=moderator_updated,json=moderatorUpdated,proto3,oneof"`
}

type NicoliveMessage_Nicoad

type NicoliveMessage_Nicoad struct {
	Nicoad *Nicoad `protobuf:"bytes,9,opt,name=nicoad,proto3,oneof"`
}

type NicoliveMessage_OverflowedChat

type NicoliveMessage_OverflowedChat struct {
	OverflowedChat *Chat `protobuf:"bytes,20,opt,name=overflowed_chat,json=overflowedChat,proto3,oneof"`
}

type NicoliveMessage_SimpleNotification

type NicoliveMessage_SimpleNotification struct {
	SimpleNotification *SimpleNotification `protobuf:"bytes,7,opt,name=simple_notification,json=simpleNotification,proto3,oneof"`
}

type NicoliveMessage_SsngUpdated

type NicoliveMessage_SsngUpdated struct {
	SsngUpdated *atoms.SSNGUpdated `protobuf:"bytes,19,opt,name=ssng_updated,json=ssngUpdated,proto3,oneof"`
}

type NicoliveMessage_TagUpdated

type NicoliveMessage_TagUpdated struct {
	TagUpdated *TagUpdated `protobuf:"bytes,17,opt,name=tag_updated,json=tagUpdated,proto3,oneof"`
}

type NicoliveOrigin

type NicoliveOrigin struct {

	// Types that are valid to be assigned to Origin:
	//
	//	*NicoliveOrigin_Chat_
	Origin isNicoliveOrigin_Origin `protobuf_oneof:"origin"`
	// contains filtered or unexported fields
}

func (*NicoliveOrigin) Descriptor deprecated

func (*NicoliveOrigin) Descriptor() ([]byte, []int)

Deprecated: Use NicoliveOrigin.ProtoReflect.Descriptor instead.

func (*NicoliveOrigin) GetChat

func (x *NicoliveOrigin) GetChat() *NicoliveOrigin_Chat

func (*NicoliveOrigin) GetOrigin

func (x *NicoliveOrigin) GetOrigin() isNicoliveOrigin_Origin

func (*NicoliveOrigin) ProtoMessage

func (*NicoliveOrigin) ProtoMessage()

func (*NicoliveOrigin) ProtoReflect

func (x *NicoliveOrigin) ProtoReflect() protoreflect.Message

func (*NicoliveOrigin) Reset

func (x *NicoliveOrigin) Reset()

func (*NicoliveOrigin) String

func (x *NicoliveOrigin) String() string

type NicoliveOrigin_Chat

type NicoliveOrigin_Chat struct {
	LiveId int64 `protobuf:"varint,1,opt,name=live_id,json=liveId,proto3" json:"live_id,omitempty"`
	// contains filtered or unexported fields
}

func (*NicoliveOrigin_Chat) Descriptor deprecated

func (*NicoliveOrigin_Chat) Descriptor() ([]byte, []int)

Deprecated: Use NicoliveOrigin_Chat.ProtoReflect.Descriptor instead.

func (*NicoliveOrigin_Chat) GetLiveId

func (x *NicoliveOrigin_Chat) GetLiveId() int64

func (*NicoliveOrigin_Chat) ProtoMessage

func (*NicoliveOrigin_Chat) ProtoMessage()

func (*NicoliveOrigin_Chat) ProtoReflect

func (x *NicoliveOrigin_Chat) ProtoReflect() protoreflect.Message

func (*NicoliveOrigin_Chat) Reset

func (x *NicoliveOrigin_Chat) Reset()

func (*NicoliveOrigin_Chat) String

func (x *NicoliveOrigin_Chat) String() string

type NicoliveOrigin_Chat_

type NicoliveOrigin_Chat_ struct {
	Chat *NicoliveOrigin_Chat `protobuf:"bytes,1,opt,name=chat,proto3,oneof"`
}

type NicoliveState

type NicoliveState struct {
	Statistics             *Statistics                   `protobuf:"bytes,1,opt,name=statistics,proto3,oneof" json:"statistics,omitempty"`
	Enquete                *Enquete                      `protobuf:"bytes,2,opt,name=enquete,proto3,oneof" json:"enquete,omitempty"`
	MoveOrder              *MoveOrder                    `protobuf:"bytes,3,opt,name=move_order,json=moveOrder,proto3,oneof" json:"move_order,omitempty"`
	Marquee                *Marquee                      `protobuf:"bytes,4,opt,name=marquee,proto3,oneof" json:"marquee,omitempty"`
	CommentLock            *CommentLock                  `protobuf:"bytes,5,opt,name=comment_lock,json=commentLock,proto3,oneof" json:"comment_lock,omitempty"`
	CommentMode            *CommentMode                  `protobuf:"bytes,6,opt,name=comment_mode,json=commentMode,proto3,oneof" json:"comment_mode,omitempty"`
	TrialPanel             *TrialPanel                   `protobuf:"bytes,7,opt,name=trial_panel,json=trialPanel,proto3,oneof" json:"trial_panel,omitempty"`
	ProgramStatus          *ProgramStatus                `protobuf:"bytes,9,opt,name=program_status,json=programStatus,proto3,oneof" json:"program_status,omitempty"`
	ModerationAnnouncement *atoms.ModerationAnnouncement `` /* 134-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*NicoliveState) Descriptor deprecated

func (*NicoliveState) Descriptor() ([]byte, []int)

Deprecated: Use NicoliveState.ProtoReflect.Descriptor instead.

func (*NicoliveState) GetCommentLock

func (x *NicoliveState) GetCommentLock() *CommentLock

func (*NicoliveState) GetCommentMode

func (x *NicoliveState) GetCommentMode() *CommentMode

func (*NicoliveState) GetEnquete

func (x *NicoliveState) GetEnquete() *Enquete

func (*NicoliveState) GetMarquee

func (x *NicoliveState) GetMarquee() *Marquee

func (*NicoliveState) GetModerationAnnouncement

func (x *NicoliveState) GetModerationAnnouncement() *atoms.ModerationAnnouncement

func (*NicoliveState) GetMoveOrder

func (x *NicoliveState) GetMoveOrder() *MoveOrder

func (*NicoliveState) GetProgramStatus

func (x *NicoliveState) GetProgramStatus() *ProgramStatus

func (*NicoliveState) GetStatistics

func (x *NicoliveState) GetStatistics() *Statistics

func (*NicoliveState) GetTrialPanel

func (x *NicoliveState) GetTrialPanel() *TrialPanel

func (*NicoliveState) ProtoMessage

func (*NicoliveState) ProtoMessage()

func (*NicoliveState) ProtoReflect

func (x *NicoliveState) ProtoReflect() protoreflect.Message

func (*NicoliveState) Reset

func (x *NicoliveState) Reset()

func (*NicoliveState) String

func (x *NicoliveState) String() string

type OperatorComment

type OperatorComment struct {
	Content  string         `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	Name     *string        `protobuf:"bytes,2,opt,name=name,proto3,oneof" json:"name,omitempty"`
	Modifier *Chat_Modifier `protobuf:"bytes,3,opt,name=modifier,proto3" json:"modifier,omitempty"`
	Link     *string        `protobuf:"bytes,4,opt,name=link,proto3,oneof" json:"link,omitempty"`
	// contains filtered or unexported fields
}

func (*OperatorComment) Descriptor deprecated

func (*OperatorComment) Descriptor() ([]byte, []int)

Deprecated: Use OperatorComment.ProtoReflect.Descriptor instead.

func (*OperatorComment) GetContent

func (x *OperatorComment) GetContent() string
func (x *OperatorComment) GetLink() string

func (*OperatorComment) GetModifier

func (x *OperatorComment) GetModifier() *Chat_Modifier

func (*OperatorComment) GetName

func (x *OperatorComment) GetName() string

func (*OperatorComment) ProtoMessage

func (*OperatorComment) ProtoMessage()

func (*OperatorComment) ProtoReflect

func (x *OperatorComment) ProtoReflect() protoreflect.Message

func (*OperatorComment) Reset

func (x *OperatorComment) Reset()

func (*OperatorComment) String

func (x *OperatorComment) String() string

type ProgramStatus

type ProgramStatus struct {
	State ProgramStatus_State `protobuf:"varint,1,opt,name=state,proto3,enum=dwango.nicolive.chat.data.ProgramStatus_State" json:"state,omitempty"`
	// contains filtered or unexported fields
}

func (*ProgramStatus) Descriptor deprecated

func (*ProgramStatus) Descriptor() ([]byte, []int)

Deprecated: Use ProgramStatus.ProtoReflect.Descriptor instead.

func (*ProgramStatus) GetState

func (x *ProgramStatus) GetState() ProgramStatus_State

func (*ProgramStatus) ProtoMessage

func (*ProgramStatus) ProtoMessage()

func (*ProgramStatus) ProtoReflect

func (x *ProgramStatus) ProtoReflect() protoreflect.Message

func (*ProgramStatus) Reset

func (x *ProgramStatus) Reset()

func (*ProgramStatus) String

func (x *ProgramStatus) String() string

type ProgramStatus_State

type ProgramStatus_State int32
const (
	ProgramStatus_Unknown ProgramStatus_State = 0
	ProgramStatus_Ended   ProgramStatus_State = 1
)

func (ProgramStatus_State) Descriptor

func (ProgramStatus_State) Enum

func (ProgramStatus_State) EnumDescriptor deprecated

func (ProgramStatus_State) EnumDescriptor() ([]byte, []int)

Deprecated: Use ProgramStatus_State.Descriptor instead.

func (ProgramStatus_State) Number

func (ProgramStatus_State) String

func (x ProgramStatus_State) String() string

func (ProgramStatus_State) Type

type Redirect

type Redirect struct {
	Uri     string               `protobuf:"bytes,1,opt,name=uri,proto3" json:"uri,omitempty"`
	Message string               `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	Wait    *durationpb.Duration `protobuf:"bytes,4,opt,name=wait,proto3" json:"wait,omitempty"`
	// contains filtered or unexported fields
}

func (*Redirect) Descriptor deprecated

func (*Redirect) Descriptor() ([]byte, []int)

Deprecated: Use Redirect.ProtoReflect.Descriptor instead.

func (*Redirect) GetMessage

func (x *Redirect) GetMessage() string

func (*Redirect) GetUri

func (x *Redirect) GetUri() string

func (*Redirect) GetWait

func (x *Redirect) GetWait() *durationpb.Duration

func (*Redirect) ProtoMessage

func (*Redirect) ProtoMessage()

func (*Redirect) ProtoReflect

func (x *Redirect) ProtoReflect() protoreflect.Message

func (*Redirect) Reset

func (x *Redirect) Reset()

func (*Redirect) String

func (x *Redirect) String() string

type SimpleNotification

type SimpleNotification struct {

	// Types that are valid to be assigned to Message:
	//
	//	*SimpleNotification_Ichiba
	//	*SimpleNotification_Quote
	//	*SimpleNotification_Emotion
	//	*SimpleNotification_Cruise
	//	*SimpleNotification_ProgramExtended
	//	*SimpleNotification_RankingIn
	//	*SimpleNotification_RankingUpdated
	//	*SimpleNotification_Visited
	Message isSimpleNotification_Message `protobuf_oneof:"message"`
	// contains filtered or unexported fields
}

func (*SimpleNotification) Descriptor deprecated

func (*SimpleNotification) Descriptor() ([]byte, []int)

Deprecated: Use SimpleNotification.ProtoReflect.Descriptor instead.

func (*SimpleNotification) GetCruise

func (x *SimpleNotification) GetCruise() string

func (*SimpleNotification) GetEmotion

func (x *SimpleNotification) GetEmotion() string

func (*SimpleNotification) GetIchiba

func (x *SimpleNotification) GetIchiba() string

func (*SimpleNotification) GetMessage

func (x *SimpleNotification) GetMessage() isSimpleNotification_Message

func (*SimpleNotification) GetProgramExtended

func (x *SimpleNotification) GetProgramExtended() string

func (*SimpleNotification) GetQuote

func (x *SimpleNotification) GetQuote() string

func (*SimpleNotification) GetRankingIn

func (x *SimpleNotification) GetRankingIn() string

func (*SimpleNotification) GetRankingUpdated

func (x *SimpleNotification) GetRankingUpdated() string

func (*SimpleNotification) GetVisited

func (x *SimpleNotification) GetVisited() string

func (*SimpleNotification) ProtoMessage

func (*SimpleNotification) ProtoMessage()

func (*SimpleNotification) ProtoReflect

func (x *SimpleNotification) ProtoReflect() protoreflect.Message

func (*SimpleNotification) Reset

func (x *SimpleNotification) Reset()

func (*SimpleNotification) String

func (x *SimpleNotification) String() string

type SimpleNotification_Cruise

type SimpleNotification_Cruise struct {
	Cruise string `protobuf:"bytes,4,opt,name=cruise,proto3,oneof"`
}

type SimpleNotification_Emotion

type SimpleNotification_Emotion struct {
	Emotion string `protobuf:"bytes,3,opt,name=emotion,proto3,oneof"`
}

type SimpleNotification_Ichiba

type SimpleNotification_Ichiba struct {
	Ichiba string `protobuf:"bytes,1,opt,name=ichiba,proto3,oneof"`
}

type SimpleNotification_ProgramExtended

type SimpleNotification_ProgramExtended struct {
	ProgramExtended string `protobuf:"bytes,5,opt,name=program_extended,json=programExtended,proto3,oneof"`
}

type SimpleNotification_Quote

type SimpleNotification_Quote struct {
	Quote string `protobuf:"bytes,2,opt,name=quote,proto3,oneof"`
}

type SimpleNotification_RankingIn

type SimpleNotification_RankingIn struct {
	RankingIn string `protobuf:"bytes,6,opt,name=ranking_in,json=rankingIn,proto3,oneof"`
}

type SimpleNotification_RankingUpdated

type SimpleNotification_RankingUpdated struct {
	RankingUpdated string `protobuf:"bytes,8,opt,name=ranking_updated,json=rankingUpdated,proto3,oneof"`
}

type SimpleNotification_Visited

type SimpleNotification_Visited struct {
	Visited string `protobuf:"bytes,7,opt,name=visited,proto3,oneof"`
}

type Statistics

type Statistics struct {
	Viewers    *int64 `protobuf:"varint,1,opt,name=viewers,proto3,oneof" json:"viewers,omitempty"`
	Comments   *int64 `protobuf:"varint,2,opt,name=comments,proto3,oneof" json:"comments,omitempty"`
	AdPoints   *int64 `protobuf:"varint,3,opt,name=ad_points,json=adPoints,proto3,oneof" json:"ad_points,omitempty"`
	GiftPoints *int64 `protobuf:"varint,4,opt,name=gift_points,json=giftPoints,proto3,oneof" json:"gift_points,omitempty"`
	// contains filtered or unexported fields
}

func (*Statistics) Descriptor deprecated

func (*Statistics) Descriptor() ([]byte, []int)

Deprecated: Use Statistics.ProtoReflect.Descriptor instead.

func (*Statistics) GetAdPoints

func (x *Statistics) GetAdPoints() int64

func (*Statistics) GetComments

func (x *Statistics) GetComments() int64

func (*Statistics) GetGiftPoints

func (x *Statistics) GetGiftPoints() int64

func (*Statistics) GetViewers

func (x *Statistics) GetViewers() int64

func (*Statistics) ProtoMessage

func (*Statistics) ProtoMessage()

func (*Statistics) ProtoReflect

func (x *Statistics) ProtoReflect() protoreflect.Message

func (*Statistics) Reset

func (x *Statistics) Reset()

func (*Statistics) String

func (x *Statistics) String() string

type TagUpdated

type TagUpdated struct {
	Tags        []*TagUpdated_Tag `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
	OwnerLocked bool              `protobuf:"varint,2,opt,name=owner_locked,json=ownerLocked,proto3" json:"owner_locked,omitempty"`
	// contains filtered or unexported fields
}

func (*TagUpdated) Descriptor deprecated

func (*TagUpdated) Descriptor() ([]byte, []int)

Deprecated: Use TagUpdated.ProtoReflect.Descriptor instead.

func (*TagUpdated) GetOwnerLocked

func (x *TagUpdated) GetOwnerLocked() bool

func (*TagUpdated) GetTags

func (x *TagUpdated) GetTags() []*TagUpdated_Tag

func (*TagUpdated) ProtoMessage

func (*TagUpdated) ProtoMessage()

func (*TagUpdated) ProtoReflect

func (x *TagUpdated) ProtoReflect() protoreflect.Message

func (*TagUpdated) Reset

func (x *TagUpdated) Reset()

func (*TagUpdated) String

func (x *TagUpdated) String() string

type TagUpdated_Tag

type TagUpdated_Tag struct {
	Text         string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	Locked       bool   `protobuf:"varint,2,opt,name=locked,proto3" json:"locked,omitempty"`
	Reserved     bool   `protobuf:"varint,3,opt,name=reserved,proto3" json:"reserved,omitempty"`
	NicopediaUri string `protobuf:"bytes,4,opt,name=nicopedia_uri,json=nicopediaUri,proto3" json:"nicopedia_uri,omitempty"`
	// contains filtered or unexported fields
}

func (*TagUpdated_Tag) Descriptor deprecated

func (*TagUpdated_Tag) Descriptor() ([]byte, []int)

Deprecated: Use TagUpdated_Tag.ProtoReflect.Descriptor instead.

func (*TagUpdated_Tag) GetLocked

func (x *TagUpdated_Tag) GetLocked() bool

func (*TagUpdated_Tag) GetNicopediaUri

func (x *TagUpdated_Tag) GetNicopediaUri() string

func (*TagUpdated_Tag) GetReserved

func (x *TagUpdated_Tag) GetReserved() bool

func (*TagUpdated_Tag) GetText

func (x *TagUpdated_Tag) GetText() string

func (*TagUpdated_Tag) ProtoMessage

func (*TagUpdated_Tag) ProtoMessage()

func (*TagUpdated_Tag) ProtoReflect

func (x *TagUpdated_Tag) ProtoReflect() protoreflect.Message

func (*TagUpdated_Tag) Reset

func (x *TagUpdated_Tag) Reset()

func (*TagUpdated_Tag) String

func (x *TagUpdated_Tag) String() string

type TrialPanel

type TrialPanel struct {
	Panel           TrialPanel_Panel `protobuf:"varint,1,opt,name=panel,proto3,enum=dwango.nicolive.chat.data.TrialPanel_Panel" json:"panel,omitempty"`
	UnqualifiedUser TrialPanel_Mode  `` /* 154-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*TrialPanel) Descriptor deprecated

func (*TrialPanel) Descriptor() ([]byte, []int)

Deprecated: Use TrialPanel.ProtoReflect.Descriptor instead.

func (*TrialPanel) GetPanel

func (x *TrialPanel) GetPanel() TrialPanel_Panel

func (*TrialPanel) GetUnqualifiedUser

func (x *TrialPanel) GetUnqualifiedUser() TrialPanel_Mode

func (*TrialPanel) ProtoMessage

func (*TrialPanel) ProtoMessage()

func (*TrialPanel) ProtoReflect

func (x *TrialPanel) ProtoReflect() protoreflect.Message

func (*TrialPanel) Reset

func (x *TrialPanel) Reset()

func (*TrialPanel) String

func (x *TrialPanel) String() string

type TrialPanel_Mode

type TrialPanel_Mode int32
const (
	TrialPanel_Allowed    TrialPanel_Mode = 0
	TrialPanel_Restricted TrialPanel_Mode = 1
	TrialPanel_Forbidden  TrialPanel_Mode = 2
)

func (TrialPanel_Mode) Descriptor

func (TrialPanel_Mode) Enum

func (x TrialPanel_Mode) Enum() *TrialPanel_Mode

func (TrialPanel_Mode) EnumDescriptor deprecated

func (TrialPanel_Mode) EnumDescriptor() ([]byte, []int)

Deprecated: Use TrialPanel_Mode.Descriptor instead.

func (TrialPanel_Mode) Number

func (TrialPanel_Mode) String

func (x TrialPanel_Mode) String() string

func (TrialPanel_Mode) Type

type TrialPanel_Panel

type TrialPanel_Panel int32
const (
	TrialPanel_Hidden  TrialPanel_Panel = 0
	TrialPanel_Display TrialPanel_Panel = 1
)

func (TrialPanel_Panel) Descriptor

func (TrialPanel_Panel) Enum

func (TrialPanel_Panel) EnumDescriptor deprecated

func (TrialPanel_Panel) EnumDescriptor() ([]byte, []int)

Deprecated: Use TrialPanel_Panel.Descriptor instead.

func (TrialPanel_Panel) Number

func (TrialPanel_Panel) String

func (x TrialPanel_Panel) String() string

func (TrialPanel_Panel) Type

Directories

Path Synopsis

Jump to